@@ -28,6 +28,7 @@ from ._parallel_backends import (FallbackToBackend, MultiprocessingBackend,
                                  LokyBackend)
 from .externals.cloudpickle import dumps, loads
 from .externals import loky
+from ._utils import eval_expr
 
 # Make sure that those two classes are part of the public joblib.parallel API
 # so that 3rd party backend implementers can import them from here.
@@ -144,13 +145,13 @@ class parallel_backend(object):
 
     It is also possible to use the distributed 'ray' backend for distributing
     the workload to a cluster of nodes. To use the 'ray' joblib backend add
-    the following lines:
+    the following lines::
 
-    >> from ray.util.joblib import register_ray
-    >> register_ray()
-    >> with parallel_backend("ray"):
-    ..     print(Parallel()(delayed(neg)(i + 1) for i in range(5)))
-    [-1, -2, -3, -4, -5]
+     >>> from ray.util.joblib import register_ray  # doctest: +SKIP
+     >>> register_ray()  # doctest: +SKIP
+     >>> with parallel_backend("ray"):  # doctest: +SKIP
+     ...     print(Parallel()(delayed(neg)(i + 1) for i in range(5)))
+     [-1, -2, -3, -4, -5]
 
     Alternatively the backend can be passed directly as an instance.
 
@@ -318,15 +319,8 @@ def _verbosity_filter(index, verbose):
 
 
 ###############################################################################
-def delayed(function, check_pickle=None):
+def delayed(function):
     """Decorator used to capture the arguments of a function."""
-    if check_pickle is not None:
-        warnings.warn('check_pickle is deprecated in joblib 0.12 and will be'
-                      ' removed in 0.13', DeprecationWarning)
-    # Try to pickle the input function, to catch the problems early when
-    # using with multiprocessing:
-    if check_pickle:
-        dumps(function)
 
     def delayed_function(*args, **kwargs):
         return function, args, kwargs
@@ -484,7 +478,9 @@ class Parallel(Logger):
         pre_dispatch: {'all', integer, or expression, as in '3*n_jobs'}
             The number of batches (of tasks) to be pre-dispatched.
             Default is '2*n_jobs'. When batch_size="auto" this is reasonable
-            default and the workers should never starve.
+            default and the workers should never starve. Note that only basic
+            arithmetics are allowed here and no modules can be used in this
+            expression.
         batch_size: int or 'auto', default: 'auto'
             The number of atomic tasks to dispatch at once to each
             worker. When individual evaluations are very fast, dispatching
@@ -520,9 +516,11 @@ class Parallel(Logger):
             in Bytes, or a human-readable string, e.g., '1M' for 1 megabyte.
             Use None to disable memmapping of large arrays.
             Only active when backend="loky" or "multiprocessing".
-        mmap_mode: {None, 'r+', 'r', 'w+', 'c'}
-            Memmapping mode for numpy arrays passed to workers.
-            See 'max_nbytes' parameter documentation for more details.
+        mmap_mode: {None, 'r+', 'r', 'w+', 'c'}, default: 'r'
+            Memmapping mode for numpy arrays passed to workers. None will 
+            disable memmapping, other modes defined in the numpy.memmap doc:
+            https://numpy.org/doc/stable/reference/generated/numpy.memmap.html
+            Also, see 'max_nbytes' parameter documentation for more details.
 
         Notes
         -----
@@ -1017,7 +1015,9 @@ class Parallel(Logger):
         else:
             self._original_iterator = iterator
             if hasattr(pre_dispatch, 'endswith'):
-                pre_dispatch = eval(pre_dispatch)
+                pre_dispatch = eval_expr(
+                    pre_dispatch.replace("n_jobs", str(n_jobs))
+                )
             self._pre_dispatch_amount = pre_dispatch = int(pre_dispatch)
 
             # The main thread will consume the first pre_dispatch items and
